import random as rnd
from neuron import h
#from neuron import gui
#h.load_file('nrngui.hoc')
import copy as cp
import numpy as np

class Panels(object):
    def __init__(self,branch,protocol,plots):
        #dep,hyp,stim,start_base,spines):
        self.spines = branch.spines
        self.cell = branch.cell
        self.plots = plots
        # self.ca_rm_theta = spines[0].head.RMECB.
        self.tau_rm = self.spines[0].head.RMECB.tau_RM
        self.alpha_RMru = self.spines[0].head.RMECB.alpha_RMru
        self.blk_RMBLK = protocol.p['Block_RMBLK']
        self.protocol = protocol
        self.dur = protocol.stimulators['IC_dep'][0][0].dur
        self.dep = protocol.stimulators['IC_dep']
        self.hyp = protocol.stimulators['IC_hyp']
        self.stim = protocol.stim
        self.start_base = protocol.p['time_start_induction_stimuli']
        self.delta_t = 5 #-(self.stim.start - self.start_base)
        self.neck_diam = self.spines[0].neck.diam
        self.AMPA_Pmax = self.spines[0].head.AMPA.Pmax
        self.AMPA_Prel = self.spines[0].head.AMPA.U_SE_init
        self.AMPA_NMDA_ratio = self.spines[0].head.NMDA.Pmax/self.spines[0].head.AMPA.Pmax
        self.NMDA_Pmax = self.spines[0].head.NMDA.Pmax
        self.NMDA_mg = self.spines[0].head.NMDA.mg
        self.NMDA_mgbk = self.spines[0].head.NMDA.mgb_k
        self.KMULT = h.KMULT
        self.KMULTP = h.KMULTP
        self.nBPAP = len(protocol.stimulators['IC_dep'][0])
        self.nstim = 25 #len(protocol.stimulators['IC_dep'])
        self.sp_delay_env = protocol.p['sp_delay_env']
        self.old_sp_delay_env = cp.deepcopy(protocol.p['sp_delay_env'])
        self.gbar_cat = protocol.p['gcatbar']
        self.clamp_dur = 120
        self.clamp_V = -20
        self.build()
        self.map()

    def build(self):
		self.box = h.HBox()
		self.box.intercept(1)
		self.box.ref(self)
		h.xpanel("")
		#h.xbutton("Erase_ALL", self.set_view)
		h.xbutton("LTP11", self.set_LTP11)
		h.xbutton("LTP12", self.set_LTP12)
		h.xbutton("LTP14", self.set_LTP14)
		h.xpanel()
		self.box.intercept(0)

    def map(self):
        #self.box.map("Stimulus control", 0, 378, 329.28, 642.24)
		self.box.map("Stimulus control" )
    def set_seclamp(self):
        self.clamp = h.SEClamp(0.5,sec=self.cell.soma)
        # print(self.clamp_dur,self.clamp_V)
        self.clamp.dur1 = self.clamp_dur
        self.clamp.amp1 = self.clamp_V
        self.clamp_graph = h.Graph()
        self.clamp_graph.addvar('I_seclamp',self.clamp._ref_i, 1,1,sec=self.cell.soma)
        h.graphList[0].append(self.clamp_graph)

    def del_seclamp(self):
        del self.clamp

    def set_LTP11(self):
		self.nBPAP = 1
		self.nstim = 70
		self.set_pulse()
		#self.plots['v'].erase_all()
		h.tstop = 250
		h.init()
		h.run(h.tstop)
        # self.dur = 4
        # self.set_pulse_dur()

    def set_LTP12(self):
		self.nBPAP = 2
		self.nstim = 50
		self.set_pulse()
		h.tstop = 250
		h.init()
		h.run(h.tstop)
        # self.dur = 8
        # self.set_pulse_dur()

    def set_LTP14(self):
		self.nBPAP = 4
		self.nstim = 25
		self.set_pulse()
		h.tstop = 250
		h.init()
		h.run(h.tstop)
        # self.dur = 15
        # self.set_pulse_dur()

    def set_spines(self):
        for spine in self.spines:
            spine.head.RMECB.tau_RM = self.tau_rm
            spine.head.RMECB.alpha_RMru = self.alpha_RMru
            spine.neck.diam = self.neck_diam
            spine.head.AMPA.Pmax = self.AMPA_Pmax
            spine.head.AMPA.U_SE_init = self.AMPA_Prel
            # print(self.AMPA_NMDA_ratio)
            if self.AMPA_NMDA_ratio > 0:
                spine.head.NMDA.Pmax = self.AMPA_Pmax * self.AMPA_NMDA_ratio
                self.NMDA_Pmax = spine.head.NMDA.Pmax
            else:
                spine.head.NMDA.Pmax = self.NMDA_Pmax

            spine.head.gcatbar_cat = self.gbar_cat
            spine.head.NMDA.mg = self.NMDA_mg
            spine.head.NMDA.mgb_k = self.NMDA_mgbk

            if self.blk_RMBLK:
                self.alpha_cai_RMBLK_tmp = spine.head.RMECB.alpha_cai_RMBLK
                spine.head.RMECB.alpha_cai_RMBLK = 0
            else:
                spine.head.RMECB.alpha_cai_RMBLK = self.alpha_cai_RMBLK_tmp

    def set_stim_start(self):
        self.stim.start = self.start_base - self.delta_t
        print("Delta t =",self.stim.start)

    def set_pulse(self):
        # Set curr inj duration
        for dc,hc in zip(self.dep, self.hyp):
            for dc2 in dc:
                dc2.dur = self.dur
        # Set nunmber of curr injections for each induction stim (nBPAPs)
        for dc,hc in zip(self.dep, self.hyp):
            for dc2 in dc[int(self.nBPAP):len(dc)]:
                dc2.dur = 0
            # for hc2 in hc:
            #     hc2.dur = 0
            #     hc2.delay = dc.delay + dc.dur # ms

        # Set nunmber of trains of curr injections, i.e. n induction stimuli
        for nst,(dc,hc) in enumerate(zip(self.dep, self.hyp)):
            if nst > self.nstim:
                for dc2 in dc:
                    dc2.dur = 0
        self.stim.number = self.nstim
        # if not self.old_sp_delay_env == self.sp_delay_env:
        #     ratio = self.sp_delay_env/self.old_sp_delay_env
        #     print self.sp_delay_env, ratio
        #     for nc,nc_nmda in zip(self.protocol.nc_stim,self.protocol.nc_stim_nmda):
        #         # delay = rnd.uniform(0,self.sp_delay_env)
        #         print nc.delay
        #         nc.delay *= ratio
        #         nc_nmda.delay *= ratio
        #         print nc.delay
        #     self.old_sp_delay_env = self.sp_delay_env
        synaptic_delays = np.linspace(0,self.sp_delay_env,len(self.spines))
        for delay,nc,nc_nmda in zip(synaptic_delays,self.protocol.nc_stim,self.protocol.nc_stim_nmda):
            # delay = rnd.uniform(0,self.sp_delay_env)
            # print(nc.delay)
            nc.delay = delay
            nc_nmda.delay = delay
            # print(nc.delay)

        print("new dur =", self.dep[0][0].dur)

    def set_cell(self):
        command = 'forall '
        for sec in self.cell.apical_sl:
            # sec.push()
            # h('for x print distance(x)')

            for seg in sec:
                xdist = h.distance(seg.x)
                if xdist > 100:
                    prev_gkabar_kad = seg.gkabar_kad
                    seg.gkabar_kad = self.KMULT*(1+xdist/100)
                    # print((seg.gkabar_kad -  prev_gkabar_kad) / prev_gkabar_kad)
                else:
                    prev_gkabar_kap = seg.gkabar_kap
                    seg.gkabar_kap = self.KMULTP*(1+xdist/100)
                    # print((seg.gkabar_kap - prev_gkabar_kap ) / prev_gkabar_kap)

    def set_view(self):
        self.plots['v'].erase_all()
        self.plots['cai'].erase_all()



    def run_short(self):
        h.tstop = 250
        h.init()
        h.continuerun(h.tstop)

    def run_long(self):
        h.tstop = 1800e3 # runs for 30 min = 1000 ms x 60 s x 30 min = 1.800.000 ms
        if h.t > 0:
            h.continuerun(1800e3 - h.t)
        else:
            h.init()
            h.run()
