# 1. provide main model python file path
model_path = "./themodel_ss.py"

# 2. path to mod files; can be 'None' if mod files in base directory of `model_path`
mod_files_path = None

# 3. Set default values for parameters (used to reset model to initial state)
# Note: should use same name as target parameter name (e.g. nBPAP and NOT nbpap) with outer key specifying section/object
# Note: parameters to be set for NEURON simulator also included here as key:value pair
# Note: function calls for handling parameter initialization can be specified as a list using 'FUNCTIONS' key
# Note: function calls would be executed after all specified parameter values have been assigned
# e.g.1: to set `panel.nstim = 10` use `{'panel' : {'nstim' : 70}}`
# e.g.2: to call `panel.set_pulse()` use `{'panel' : {'FUNCTIONS' : ['set_pulse()']}}`
default_parameters = {'panel' : {'nBPAP':  1, 'nstim': 70, 'FUNCTIONS':['set_pulse()']},
                      'tstop' : 250}

# 4. Specify the vector objects that are being recorded during simulation
# Note: format is {display_label : vector_object_name}
# Note: time vector should use key as 'TIME' and is mandatory input
recorded_vectors = [{'TIME' : 't'},
                    {'soma(0.5)' : 'v' },
                    {'branch[38](0.1)' : 'v_vec_base'},
                    {'spine1_head[0]_v' : 'v_vec_spine1_matrix[0]'},
                    {'spine1_head[1]_v' : 'v_vec_spine1_matrix[1]'},
                    {'spine1_head[2]_v' : 'v_vec_spine1_matrix[2]'},
                    {'spine1_head[3]_v' : 'v_vec_spine1_matrix[3]'},
                    {'spine1_head[4]_v' : 'v_vec_spine1_matrix[4]'},
                    {'spine1_head[5]_v' : 'v_vec_spine1_matrix[5]'},
                    {'spine1_head[6]_v' : 'v_vec_spine1_matrix[6]'},
                    {'spine1_head[7]_v' : 'v_vec_spine1_matrix[7]'},
                    {'spine1_head[8]_v' : 'v_vec_spine1_matrix[8]'},
                    {'spine1_head[9]_v' : 'v_vec_spine1_matrix[9]'},
                    {'spine1_head[10]_v' : 'v_vec_spine1_matrix[10]'},
                    {'spine2_head[0]_v' : 'v_vec_spine2_matrix[0]'},
                    {'spine2_head[1]_v' : 'v_vec_spine2_matrix[1]'},
                    {'spine2_head[2]_v' : 'v_vec_spine2_matrix[2]'},
                    {'spine2_head[3]_v' : 'v_vec_spine2_matrix[3]'},
                    {'spine2_head[4]_v' : 'v_vec_spine2_matrix[4]'},
                    {'spine2_head[5]_v' : 'v_vec_spine2_matrix[5]'},
                    {'theta1' : 'theta1'},
                    {'theta2' : 'theta2'},
                    {'theta3' : 'theta3'},
                    {'spine1_head[0]_cai' : 'cai_vec_spine1_matrix[0]'},
                    {'spine1_head[1]_cai' : 'cai_vec_spine1_matrix[1]'},
                    {'spine1_head[2]_cai' : 'cai_vec_spine1_matrix[2]'},
                    {'spine1_head[3]_cai' : 'cai_vec_spine1_matrix[3]'},
                    {'spine1_head[4]_cai' : 'cai_vec_spine1_matrix[4]'},
                    {'spine1_head[5]_cai' : 'cai_vec_spine1_matrix[5]'},
                    {'spine1_head[6]_cai' : 'cai_vec_spine1_matrix[6]'},
                    {'spine1_head[7]_cai' : 'cai_vec_spine1_matrix[7]'},
                    {'spine1_head[8]_cai' : 'cai_vec_spine1_matrix[8]'},
                    {'spine1_head[9]_cai' : 'cai_vec_spine1_matrix[9]'},
                    {'spine1_head[10]_cai' : 'cai_vec_spine1_matrix[10]'},
                    {'spine2_head[0]_cai' : 'cai_vec_spine2_matrix[0]'},
                    {'spine2_head[1]_cai' : 'cai_vec_spine2_matrix[1]'},
                    {'spine2_head[2]_cai' : 'cai_vec_spine2_matrix[2]'},
                    {'spine2_head[3]_cai' : 'cai_vec_spine2_matrix[3]'},
                    {'spine2_head[4]_cai' : 'cai_vec_spine2_matrix[4]'},
                    {'spine2_head[5]_cai' : 'cai_vec_spine2_matrix[5]'}]
